aboutsummaryrefslogtreecommitdiffstats
path: root/matrix-api.h
diff options
context:
space:
mode:
authorRichard van der Hoff <richard@matrix.org>2015-10-16 15:47:59 +0100
committerRichard van der Hoff <richard@matrix.org>2015-10-16 16:47:30 +0100
commit14bd2551add446e7209f151a3fa4cfa213a682da (patch)
tree2d8eac0cb064d784fc4cd14a04e7b660e44603f9 /matrix-api.h
parentf329642569a47e273e92671aee3e3cf88118d079 (diff)
downloadpurple-matrix-14bd2551add446e7209f151a3fa4cfa213a682da.tar.gz
Switch to v2 /sync API
initialSync is going away, so switch over before we get too far into the old way.
Diffstat (limited to 'matrix-api.h')
-rw-r--r--matrix-api.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/matrix-api.h b/matrix-api.h
index d81c027..6783fe8 100644
--- a/matrix-api.h
+++ b/matrix-api.h
@@ -55,14 +55,14 @@ typedef void (*MatrixApiCallback)(MatrixAccount *account,
/**
* call the /initialsync API
*
* @param account The MatrixAccount for which to make the request
* @param callback Function to be called when the request completes
* @param user_data Opaque data to be passed to the callback
*/
-PurpleUtilFetchUrlData *matrix_initialsync(MatrixAccount *account,
- MatrixApiCallback callback,
- gpointer user_data);
+PurpleUtilFetchUrlData *matrix_sync(MatrixAccount *account,
+ MatrixApiCallback callback,
+ gpointer user_data);
#endif
@@ -55,14 +55,14 @@ typedef void (*MatrixApiCallback)(MatrixAccount *account,
/**
- * call the /initialsync API
+ * call the /sync API
*
* @param account The MatrixAccount for which to make the request